@@ -34,7 +34,7 @@ class InitConnectionPool:
                     pool = None
                     # 依据数据库类型进行链接池创建
                     if conn_info.dialect == "postgresql":
-                        pool = InitConnectionPool.create_pool_postgresql(conn_info)
+                        pool = await InitConnectionPool.create_pool_postgresql(conn_info)
                     elif conn_info.dialect == "mysql":
                         pool = await InitConnectionPool.create_pool_mysql(conn_info)
                     elif conn_info.dialect == "mongodb":
@@ -45,16 +45,19 @@ class InitConnectionPool:
                         options.database[conn_info.name] = (pool, conn_info.dialect)
 
     @staticmethod
-    def create_pool_postgresql(conn_info: ConnectionInfo):
+    async def create_pool_postgresql(conn_info: ConnectionInfo):
         """
         创建postgresql 异步连接池
         :param conn_info: 连接信息
         :return: AsyncConnectionPool
         """
         if conn_info.async_enable:
-            from psycopg_pool import AsyncConnectionPool
-            conn_info_string = f"postgresql://{conn_info.user}:{conn_info.password}@{conn_info.host}:{conn_info.port}/{conn_info.db_name}"
-            return AsyncConnectionPool(conn_info_string)
+            from aiopg import create_pool
+            # conn_info_string = f"postgres://{conn_info.user}:{conn_info.password}@{conn_info.host}:{conn_info.port}/{conn_info.db_name}"
+            pool = await create_pool(host=conn_info.host, port=conn_info.port, user=conn_info.user,
+                                     password=conn_info.password,
+                                     database=conn_info.db_name)
+            return pool
         else:
             raise NotImplementedError
 
@@ -85,6 +88,13 @@ class InitConnectionPool:
         if conn_info.async_enable:
             import motor
             conn_info_string = f"mongodb://{conn_info.user}:{conn_info.password}@{conn_info.host}:{conn_info.port}"
+            if conn_info.params:
+                if conn_info.params == "LDAP":
+                    conn_info_string += "/?authMechanism=PLAIN"
+                elif conn_info.params == "Password":
+                    conn_info_string += "/?authSource=admin"
+                elif conn_info.params == "X509":
+                    conn_info_string += "/?authMechanism=MONGODB-X509"
             pool = motor.motor_tornado.MotorClient(conn_info_string)
             return pool
         else:
@@ -105,4 +115,3 @@ class InitConnectionPool:
             return pool
         else:
             raise NotImplementedError
-
