@@ -40,20 +40,21 @@ class StatusCode:
 
     REQUEST_PARAM_ERROR = ("A0300", "用户请求参数错误")
     INVALID_USER_INPUT = ("A0301", "无效的用户输入")
-    Insecure_Transport_Error = ("A0303", "OAuth 2 必须使用 https.")
-    Invalid_Request_Error = ("A0303", "无效的请求")
-    Invalid_Client_Error = ("A0304", "无效客户端信息")
-    Invalid_Grant_Error = ("A0305", "无效授权类型")
-    Unauthorized_Client_Error = ("A0306", "未授权客户端信息")
-    Unsupported_GrantType_Error = ("A0306", "不支持的授权类型")
-    Invalid_Scope_Error = ("A0307", "请求的作用域无效、未知或格式不正确")
-    Access_Denied_Error = ("A0308", "请求被拒绝")
-    Missing_Authorization_Error = ("A0309", "请求headers中缺少 Authorization 参数")
-    Unsupported_Token_Type_Error = ("A0310", "不支持的token类型")
-    Missing_Code_Exception = ("A0311", '请求响应中缺少 "code"')
-    Missing_Token_Exception = ("A0312", '请求响应中缺少 "access_token"')
-    Missing_Token_Type_Exception = ("A0313", '请求响应中缺少 "token_type"')
-    Mismatching_State_Exception = ("A0314", "CSRF告警！请求和响应中的状态不相等")
+    INSECURE_TRANSPORT_ERROR = ("A0302", "OAuth 2 必须使用 https.")
+    INVALID_REQUEST_ERROR = ("A0303", "无效的请求")
+    INVALID_CLIENT_ERROR = ("A0304", "无效客户端信息")
+    INVALID_GRANT_ERROR = ("A0305", "无效授权类型")
+    UNAUTHORIZED_CLIENT_ERROR = ("A0306", "未授权客户端信息")
+    UNSUPPORTED_RESPONSE_TYPE_ERROR = ("A0307", "不支持的响应类型")
+    UNSUPPORTED_GRANT_TYPE_ERROR = ("A0308", "不支持的授权类型")
+    INVALID_SCOPE_ERROR = ("A0309", "请求的作用域无效、未知或格式不正确")
+    ACCESS_DENIED_ERROR = ("A0310", "请求被拒绝")
+    MISSING_AUTHORIZATION_ERROR = ("A0311", "请求HEADERS中缺少 AUTHORIZATION 参数")
+    UNSUPPORTED_TOKEN_TYPE_ERROR = ("A0312", "不支持的TOKEN类型")
+    MISSING_CODE_EXCEPTION = ("A0313", '请求响应中缺少 "CODE"')
+    MISSING_TOKEN_EXCEPTION = ("A0314", '请求响应中缺少 "ACCESS_TOKEN"')
+    MISSING_TOKEN_TYPE_EXCEPTION = ("A0315", '请求响应中缺少 "TOKEN_TYPE"')
+    MISMATCHING_STATE_EXCEPTION = ("A0316", "CSRF告警！请求和响应中的状态不相等")
 
     # REQUIRED_PARAM_IS_EMPTY = ("A0310", "请求缺少必要参数:{}")
     @staticmethod
